# Appendix B: Required Graph API Permissions

| Permission | Type | Purpose |
|------------|------|---------|
| `TeamsUserConfiguration.Read.All` | Application | Read user voice configuration |
| `TeamsTelephoneNumber.Read.All` | Application | Read phone number inventory |
| `TeamsTelephoneNumber.ReadWrite.All` | Application | Assign/unassign/update numbers |
| `TeamsPolicyUserAssign.ReadWrite.All` | Application | Assign policies to users |
| `User.Read.All` | Application | Read user profiles |
| `Directory.Read.All` | Application | Read tenant information |

---

*Document generated by PRD Generator skill*
